<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="体检记录ID" prop="orderId">
        <el-input
          v-model="queryParams.orderId"
          placeholder="请输入体检记录ID"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="项目ID" prop="proId">
        <el-input
          v-model="queryParams.proId"
          placeholder="请输入项目ID"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>


      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['hosp:detail:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['hosp:detail:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['hosp:detail:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['hosp:detail:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="detailList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="体检详情id" align="center" prop="orderDetailId" />
      <el-table-column label="体检记录ID" align="center" prop="orderId" />
      <el-table-column label="项目名" align="center" prop="proName" />
      <el-table-column label="所选项目类型" align="center" prop="proType" />
      <el-table-column label="标准结果(关联标准表)" align="center" prop="stanId" />
      <el-table-column label="体检结果" align="center" prop="proResult" />
      <el-table-column label="项目建议(关联建议表)" align="center" prop="proAdvice" />
      <el-table-column label="体检状态" align="center" prop="tjStatus" >
        <template slot-scope="scope">
                    <span>{{scope.row.tjStatus == '1' ? '已检' : '未检'}}</span>
                </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.createTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="创建人" align="center" prop="createBy" />
      <el-table-column label="修改人" align="center" prop="updateBy" />
      <el-table-column label="修改时间" align="center" prop="updateTime" width="180">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.updateTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <!-- <el-table-column label="删除标注" align="center" prop="deleted" /> -->
      <el-table-column label="异常描述(0表示正常1偏高-1偏低)" align="center" prop="exceptiondesc" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['hosp:detail:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['hosp:detail:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    
    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改体检项目明细对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="体检记录ID" prop="orderId">
          <el-input v-model="form.orderId" placeholder="请输入体检记录ID" />
        </el-form-item>
        <el-form-item label="项目ID" prop="proId">
          <el-input v-model="form.proId" placeholder="请输入项目ID" />
        </el-form-item>
        <el-form-item label="标准结果(关联标准表)" prop="stanId">
          <el-input v-model="form.stanId" placeholder="请输入标准结果(关联标准表)" />
        </el-form-item>
        <el-form-item label="体检结果" prop="proResult">
          <el-input v-model="form.proResult" placeholder="请输入体检结果" />
        </el-form-item>
        <el-form-item label="项目建议(关联建议表)" prop="proAdvice">
          <el-input v-model="form.proAdvice" placeholder="请输入项目建议(关联建议表)" />
        </el-form-item>
        <el-form-item label="删除标注" prop="deleted">
          <el-input v-model="form.deleted" placeholder="请输入删除标注" />
        </el-form-item>
        <el-form-item label="异常描述(0表示正常1偏高-1偏低)" prop="exceptiondesc">
          <el-input v-model="form.exceptiondesc" placeholder="请输入异常描述(0表示正常1偏高-1偏低)" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listDetail, getDetail, delDetail, addDetail, updateDetail } from "@/api/hosp/detail";

export default {
  name: "Detail",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 体检项目明细表格数据
      detailList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        orderId: null,
        proId: null,
        proType: null,
        stanId: null,
        proResult: null,
        proAdvice: null,
        tjStatus: null,
        deleted: null,
        exceptiondesc: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        deleted: [
          { required: true, message: "", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询体检项目明细列表 */
    getList() {
      this.loading = true;
      listDetail(this.queryParams).then(response => {
        this.detailList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        orderDetailId: null,
        orderId: null,
        proId: null,
        proType: null,
        stanId: null,
        proResult: null,
        proAdvice: null,
        tjStatus: "0",
        createTime: null,
        createBy: null,
        updateBy: null,
        updateTime: null,
        deleted: null,
        exceptiondesc: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.orderDetailId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加体检项目明细";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const orderDetailId = row.orderDetailId || this.ids
      getDetail(orderDetailId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改体检项目明细";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.orderDetailId != null) {
            updateDetail(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDetail(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const orderDetailIds = row.orderDetailId || this.ids;
      this.$modal.confirm('是否确认删除体检项目明细编号为"' + orderDetailIds + '"的数据项？').then(function() {
        return delDetail(orderDetailIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('hosp/detail/export', {
        ...this.queryParams
      }, `detail_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
